@@ -9,7 +9,7 @@ from . import textpreprocessing
 from . import compactmodel_io
 from . import dtm
 
-from .textpreprocessing import spacy_tokenize as tokenize
+from .textpreprocessing import tokenize
 from .textpreprocessing import text_preprocessor, standard_text_preprocessor_1
 
 from .wordembed import load_word2vec_model, load_fasttext_model, load_poincare_model, shorttext_to_avgvec
